# Feature requests and bug reports

## Labels

Feature requests in github are labelled with "enhancement" for plaso we additionally label them with one or more of the following "focus area" labels:

* analysis; changes to analysis plug-ins
* core; changes to the core
* deployment; changes to deployment or development utility scripts
* parsers; changes to parsers and parser plug-ins
* testing; changes to improve testing or code health
* UX; changes to user experience

## Milestones

After every release the plaso maintainers will go over the open feature requests and bug reports and determine which of the issues we are going to give priority to work on and marked by a corresponding milestone.

Note that this is no guarantee that the feature will actually be implemented in the next release. This is depend on other factors e.g. available time, show stopper bugs, etc.

